/* Config for win32 */

#define HAVE__EXIT
#undef HAVE_SYSCONF
#undef HAVE_GETPGID
#undef HAVE_SETPGID
#undef HAVE_TCGETPGRP
#undef HAVE_TCSETPGRP
#undef HAVE_CTERMID
#undef HAVE_TTYNAME
#undef HAVE_GETSID
#undef HAVE_SETREUID
#undef HAVE_SETREGID
#undef HAVE_FSYNC
#undef HAVE_FDATASYNC
#undef HAVE_POLL
